2024-03-29 Version: 1.3.2
- Update API ConfigureDtsJob: add param MaxDu.
- Update API ConfigureDtsJob: add param MinDu.
- Update API ConfigureDtsJob: add param ResourceGroupId.
- Update API ConfigureMigrationJob: add param ResourceGroupId.
- Update API ConfigureMigrationJobAlert: add param ResourceGroupId.
- Update API ConfigureSubscription: add param MaxDu.
- Update API ConfigureSubscription: add param MinDu.
- Update API ConfigureSubscription: add param ResourceGroupId.
- Update API ConfigureSubscriptionInstance: add param ResourceGroupId.
- Update API ConfigureSubscriptionInstanceAlert: add param ResourceGroupId.
- Update API ConfigureSynchronizationJob: add param ResourceGroupId.
- Update API ConfigureSynchronizationJobAlert: add param ResourceGroupId.
- Update API ConfigureSynchronizationJobReplicatorCompare: add param ResourceGroupId.
- Update API CountJobByCondition: add param ResourceGroupId.
- Update API CreateConsumerChannel: add param ResourceGroupId.
- Update API CreateConsumerGroup: add param ResourceGroupId.
- Update API CreateDedicatedClusterMonitorRule: add param ResourceGroupId.
- Update API CreateDtsInstance: add param MaxDu.
- Update API CreateDtsInstance: add param MinDu.
- Update API CreateJobMonitorRule: add param ResourceGroupId.
- Update API CreateMigrationJob: add param ResourceGroupId.
- Update API CreateReverseDtsJob: add param ResourceGroupId.
- Update API CreateSubscriptionInstance: add param ResourceGroupId.
- Update API CreateSynchronizationJob: add param ResourceGroupId.
- Update API DeleteConsumerChannel: add param ResourceGroupId.
- Update API DeleteConsumerGroup: add param ResourceGroupId.
- Update API DeleteDtsJob: add param ResourceGroupId.
- Update API DeleteDtsJob: add param ZeroEtlJob.
- Update API DeleteDtsJobs: add param ResourceGroupId.
- Update API DeleteDtsJobs: add param ZeroEtlJob.
- Update API DeleteMigrationJob: add param ResourceGroupId.
- Update API DeleteSubscriptionInstance: add param ResourceGroupId.
- Update API DeleteSynchronizationJob: add param ResourceGroupId.
- Update API DescribeCheckJobs: add param ResourceGroupId.
- Update API DescribeClusterOperateLogs: add param ResourceGroupId.
- Update API DescribeClusterUsedUtilization: add param ResourceGroupId.
- Update API DescribeConnectionStatus: add param ResourceGroupId.
- Update API DescribeConsumerChannel: add param ResourceGroupId.
- Update API DescribeConsumerGroup: add param ResourceGroupId.
- Update API DescribeDTSIP: add param ResourceGroupId.
- Update API DescribeDataCheckReportUrl: add param ResourceGroupId.
- Update API DescribeDataCheckTableDetails: add param ResourceGroupId.
- Update API DescribeDataCheckTableDiffDetails: add param ResourceGroupId.
- Update API DescribeDedicatedCluster: add param ResourceGroupId.
- Update API DescribeDedicatedClusterMonitorRule: add param ResourceGroupId.
- Update API DescribeDtsEtlJobVersionInfo: add param ResourceGroupId.
- Update API DescribeDtsJobDetail: add param ResourceGroupId.
- Update API DescribeDtsJobDetail: add param ZeroEtlJob.
- Update API DescribeDtsJobDetail: update response param.
- Update API DescribeDtsJobs: add param InstanceId.
- Update API DescribeDtsJobs: add param InstanceType.
- Update API DescribeDtsJobs: add param ZeroEtlJob.
- Update API DescribeDtsJobs: update response param.
- Update API DescribeDtsServiceLog: add param ResourceGroupId.
- Update API DescribeDtsServiceLog: add param ZeroEtlJob.
- Update API DescribeEndpointSwitchStatus: add param ResourceGroupId.
- Update API DescribeEtlJobLogs: add param ResourceGroupId.
- Update API DescribeInitializationStatus: add param ResourceGroupId.
- Update API DescribeJobMonitorRule: add param ResourceGroupId.
- Update API DescribeMetricList: add param ResourceGroupId.
- Update API DescribeMigrationJobAlert: add param ResourceGroupId.
- Update API DescribeMigrationJobDetail: add param ResourceGroupId.
- Update API DescribeMigrationJobStatus: add param ResourceGroupId.
- Update API DescribeMigrationJobs: add param ResourceGroupId.
- Update API DescribePreCheckStatus: add param ResourceGroupId.
- Update API DescribePreCheckStatus: add param ZeroEtlJob.
- Update API DescribeSubscriptionInstanceAlert: add param ResourceGroupId.
- Update API DescribeSubscriptionInstanceStatus: add param ResourceGroupId.
- Update API DescribeSubscriptionInstances: add param ResourceGroupId.
- Update API DescribeSubscriptionMeta: add param ResourceGroupId.
- Update API DescribeSynchronizationJobAlert: add param ResourceGroupId.
- Update API DescribeSynchronizationJobReplicatorCompare: add param ResourceGroupId.
- Update API DescribeSynchronizationJobStatus: add param ResourceGroupId.
- Update API DescribeSynchronizationJobStatusList: add param ResourceGroupId.
- Update API DescribeSynchronizationJobs: add param ResourceGroupId.
- Update API DescribeSynchronizationObjectModifyStatus: add param ResourceGroupId.
- Update API DescribeTagKeys: add param ResourceGroupId.
- Update API DescribeTagValues: add param ResourceGroupId.
- Update API InitDtsRdsInstance: add param ResourceGroupId.
- Update API InitDtsRdsInstance: update response param.
- Update API ListDedicatedCluster: add param ResourceGroupId.
- Update API ListTagResources: add param ResourceGroupId.
- Update API ModifyConsumerChannel: add param ResourceGroupId.
- Update API ModifyConsumerGroupPassword: add param ResourceGroupId.
- Update API ModifyConsumptionTimestamp: add param ResourceGroupId.
- Update API ModifyDedicatedCluster: add param ResourceGroupId.
- Update API ModifyDtsJob: add param ResourceGroupId.
- Update API ModifyDtsJob: add param ZeroEtlJob.
- Update API ModifyDtsJobConfig: add param ResourceGroupId.
- Update API ModifyDtsJobDedicatedCluster: add param ResourceGroupId.
- Update API ModifyDtsJobDuLimit: add param ResourceGroupId.
- Update API ModifyDtsJobEndpoint: add param ResourceGroupId.
- Update API ModifyDtsJobName: add param ResourceGroupId.
- Update API ModifyDtsJobName: add param ZeroEtlJob.
- Update API ModifyDtsJobPassword: add param ResourceGroupId.
- Update API ModifyDtsJobPassword: add param ZeroEtlJob.
- Update API ModifyDynamicConfig: add param ResourceGroupId.
- Update API ModifySubscription: add param ResourceGroupId.
- Update API ModifySubscriptionObject: add param ResourceGroupId.
- Update API ModifySynchronizationObject: add param ResourceGroupId.
- Update API RenewInstance: add param ResourceGroupId.
- Update API ResetDtsJob: add param ResourceGroupId.
- Update API ResetSynchronizationJob: add param ResourceGroupId.
- Update API ReverseTwoWayDirection: add param ResourceGroupId.
- Update API ShieldPrecheck: add param ResourceGroupId.
- Update API SkipPreCheck: add param ResourceGroupId.
- Update API StartDtsJob: add param ResourceGroupId.
- Update API StartDtsJob: add param ZeroEtlJob.
- Update API StartDtsJobs: add param ResourceGroupId.
- Update API StartDtsJobs: add param ZeroEtlJob.
- Update API StartMigrationJob: add param ResourceGroupId.
- Update API StartReverseWriter: add param ResourceGroupId.
- Update API StartSubscriptionInstance: add param ResourceGroupId.
- Update API StartSynchronizationJob: add param ResourceGroupId.
- Update API StopDedicatedCluster: add param ResourceGroupId.
- Update API StopDtsJob: add param ResourceGroupId.
- Update API StopDtsJob: add param ZeroEtlJob.
- Update API StopDtsJobs: add param ResourceGroupId.
- Update API StopDtsJobs: add param ZeroEtlJob.
- Update API StopMigrationJob: add param ResourceGroupId.
- Update API SummaryJobDetail: add param ResourceGroupId.
- Update API SummaryJobDetail: add param ZeroEtlJob.
- Update API SuspendDtsJob: add param ResourceGroupId.
- Update API SuspendDtsJob: add param ZeroEtlJob.
- Update API SuspendDtsJobs: add param ResourceGroupId.
- Update API SuspendDtsJobs: add param ZeroEtlJob.
- Update API SuspendMigrationJob: add param ResourceGroupId.
- Update API SuspendSynchronizationJob: add param ResourceGroupId.
- Update API SwitchPhysicalDtsJobToCloud: add param ResourceGroupId.
- Update API SwitchSynchronizationEndpoint: add param ResourceGroupId.
- Update API TagResources: add param ResourceGroupId.
- Update API TransferInstanceClass: add param ResourceGroupId.
- Update API TransferPayType: add param ResourceGroupId.
- Update API UntagResources: add param ResourceGroupId.
- Update API UpgradeTwoWay: add param ResourceGroupId.
- Update API WhiteIpList: add param ResourceGroupId.
- Update API WhiteIpList: add param ZeroEtlJob.


2024-02-21 Version: 1.3.1
- Update API ConfigureDtsJob: add param MaxDu.
- Update API ConfigureDtsJob: add param MinDu.
- Update API ConfigureSubscription: add param MaxDu.
- Update API ConfigureSubscription: add param MinDu.
- Update API CreateDtsInstance: add param MaxDu.
- Update API CreateDtsInstance: add param MinDu.
- Update API DescribeDtsJobDetail: update response param.
- Update API DescribeDtsJobs: update response param.


2023-12-21 Version: 1.3.0
- Generated python2 2020-01-01 for Dts.

2023-09-19 Version: 1.2.1
- Generated python2 2020-01-01 for Dts.

2023-09-15 Version: 1.2.0
- Generated python2 2020-01-01 for Dts.

2023-08-10 Version: 1.1.0
- Generated python2 2020-01-01 for Dts.

